/**
 * @file
 * Provides JavaScript functionality.
 */

/* global d3, entityMeshData */
(function (Drupal, once) {
  /**
   * Attaches behavior to initialize the Entity Mesh graph.
   */
  Drupal.behaviors.content_first = {
    attach(context, settings) {
      once('content-first', '#content-first', context).forEach((element) => {
        element.classList.add('processed');
        element.querySelector('#copy-button').addEventListener('click', this.copyContent);
      })
    },
    /**
     * Copies the text content of the element with the ID 'content-first-content' to the clipboard.
     * If the element is not found, an alert is shown to the user.
     * If the copy operation fails, an error is logged to the console.
     */
    copyContent() {
      const div = document.getElementById("content-first-content");
      if (!div) {
        alert("No element with the ID 'content-first-content' was found.");
        return;
      }
      const contentToCopy = div.innerText;
      navigator.clipboard.writeText(contentToCopy)
        .catch(err => {
          console.error("Failed to copy text: ", err);
        });
    }
  }

})(Drupal, once);
